README CONTENT
=======
* Introduction
* Software requirements
* Setup
* Input file formats
* Output file formats
* Examples
* Description of the algorithm
* Help
* How to cite
* Licensing


INTRODUCTION
============

SequencesNetworkGenerator is a network generating algorithm. 

Given a set of genes, SequencesNetworkGenerator generate a genetic networked named Common Substring Network [CSN] that represents similarities among the genes in the set.

CSN enables inferring novel information related to the genes' functionality and expression levels. 

SequencesNetworkGenerator is implemented in MATLAB. Please check the [Downloads](https://www.cs.tau.ac.il/~tamirtul/CSN-Autogen "Software Downloads") page for the most recent release.


SOFTWARE REQUIREMENTS
=====================

For running the SequencesNetworkGenerator analysis (e.g., examples 1 and 2): 

* MATLAB, Bioinformatics Toolbox, Statistics and Machine Learning Toolbox

These additional function is packaged with the SequencesNetworkGenerator code:  

* **inifile.m** for reading INI settings files: <https://www.mathworks.com/matlabcentral/fileexchange/17177-ini2struct>  


WORKFLOW
========

1. Place the SequencesNetworkGenerator directory with the code on your computer.

2. Open the `D:\BASIC\CODE\SequencesNetworkGenerator\src\SequencesNetworkGenerator.m` and update the path to the config file `\SequencesNetworkGenerator\CSN.ini`

3. Download your sequence set in FASTA format and place the file in the `\SequencesNetworkGenerator\data` directory.

4. Open the `\SequencesNetworkGenerator\CSN.ini` file in a text editor and adjust the input\output parameters as needed (see **Description of the algorithm** and the `safe.ini` file itself for a more detailed explanation of the parameters).

5. Run `SequencesNetworkGenerator.m`.

6. The results will be stored in the outputs directory. (Default: `\SequencesNetworkGenerator\out`)


INPUTS 
======
1. Path to  the ini file: Default: `D:\BASIC\CODE\SequencesNetworkGenerator\CSN.ini`

2. FASTA file path of sequences set. It can be download from NCBI cite.

3. Path to outputs directory. (Default: `\SequencesNetworkGenerator\out`)

4. Algorithm parameters. 

OUTPUTS
=======
1. CSN_analysis.txt: basic analysis of the CSN graph.

2. CSN_graph.txt: CSN edges list for networks' presentation and analysis tools like Cytoscape.


EXAMPLES
========
Note: Example files are stored in the `\SequencesNetworkGenerator\data` directory.

1. Update the config file path, the data directory path, and the output directory path to your `\SequencesNetworkGenerator\` location.

2. Run `SequencesNetworkGenerator.m` with the default parameters. 

3. Check your results in the `\SequencesNetworkGenerator\out` directory.


DESCRIPTION OF THE ALGORITHM
============================

All parameters (paths, thresholds, Sequence Type steps, etc.) are specified in the `safe.ini` file.


Input data
----------
A set of sequences from the translated or untranslated region of the genes.


Algorithm
---------
This subsection gives an in-depth look at the different steps that generate the CSN graph efficiently.

For a given set of genomic sequences:

1. Calculates the Normalized-chimeraARS scores for all pairs of genomic sequences by using separate Suffix Array for each sequence. 

2. Summarized the scores in a matrix (score matrix). 

3. This matrix is then transformed into a correlation matrix (which based on correlations between rows in the scores matrix). 

4. The correlations matrix represents an undirected weighted graph where an edge's weight is corresponding to a score in the correlation matrix. 

5. In this graph, edges with low values (related to low similarity) are removed to make sure that the edges represent high similarity scores and thus are meaningful ones. 

6. Greedily add a minimal number of edges to the graph between connected components to make the graph connected.  

7. The sequence-based graph is embedded in a two-dimensional layout 

8. Output the results:
    a) If the number of nodes is less than 100 - displayed as the sequence's Common Substring Network.
    b) Print a basic analysis of the CSN graph.
    c) Print the CSN edges list for the networks' presentation.

HELP
====

Please direct all questions/comments to Maya Galili (<mayavav@gmail.com>).

Code updates will be published in the article cite <https://www.mathworks.com/matlabcentral/fileexchange/17177-ini2struct>.


HOW TO CITE
===========
> Galili, M., Tuller, T. (2019) CSN:  Unsupervised Approach for Inferring Biological Networks based on the Genome Alone. 


AUTHORS CONTACT INFORMATION:
============================
Maya Galili <mayavav@gmail.com>

Tamir Tuller <tamirtul@gmail.com>


LICENSING
=========

Copyright (c) 2016 Maya Galili, Tamir Tuller

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE