% % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
% SCRIPT GOAL:
%  1. Organize genes in a network graph by their nucleotide or amino acid sequences
%  2. Analyze network features
%
% INPUT:
%  Algorithm config parameters: described in the CSN.ini file.
%  sequence set: fasta file described in the CSN.ini file.
% 
% OUTPUT:
%  Analysis_results.txt: short network's analysis report
%  CSN_graph.txt: file contain graph edges list - for Cytoscape use
%
% 
% REFERENCE:
%   Galili, M., Tuller, T. (2019) CSN:  Unsupervised Approach for 
%      Inferring Biological Networks based on the Genome Alone. 
% 
% Maya Galili, Apr 2017
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %

clear;

config_file = 'D:\BASIC\CODE\SequencesNetworkGenerator\CSN.ini';

if isfile(config_file)
    [config] = read_config(config_file);
else
    error([config_file ' config file does not exist!']);
end

fasta_file = config.FASTA_FILE_NM;
if isfile(fasta_file)
    [sequence_name_arr, sequence_arr] = read_fasta(fasta_file);
else
    error([fasta_file ' fasta file does not exist!']);
end

[graph_matrix] = run_csn(config, sequence_arr, sequence_name_arr);